summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/oscar/liboscar/oscarutils.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/oscar/liboscar/oscarutils.h')
-rw-r--r--kopete/protocols/oscar/liboscar/oscarutils.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/kopete/protocols/oscar/liboscar/oscarutils.h b/kopete/protocols/oscar/liboscar/oscarutils.h
index bf8b5aba..a9cd921c 100644
--- a/kopete/protocols/oscar/liboscar/oscarutils.h
+++ b/kopete/protocols/oscar/liboscar/oscarutils.h
@@ -19,9 +19,9 @@
#ifndef _OSCARUTILS_H_
#define _OSCARUTILS_H_
-#include <qglobal.h>
-#include <qvaluelist.h>
-#include <qstring.h>
+#include <tqglobal.h>
+#include <tqvaluelist.h>
+#include <tqstring.h>
#include "oscartypes.h"
#include "buffer.h"
@@ -29,7 +29,7 @@ namespace Oscar
{
///Normalize the contact name to all lowercase and no spaces
-KOPETE_EXPORT QString normalize( const QString& );
+KOPETE_EXPORT TQString normalize( const TQString& );
///compare TLVs for equality
KOPETE_EXPORT bool operator==( TLV, TLV );
@@ -37,13 +37,13 @@ KOPETE_EXPORT bool operator==( TLV, TLV );
/**
* Find the TLV corresponding to the type in the list
*/
-KOPETE_EXPORT TLV findTLV( const QValueList<TLV>&, int type );
+KOPETE_EXPORT TLV findTLV( const TQValueList<TLV>&, int type );
/**
* Update TLVs of SSI item from TLV list if necessary
* \return true if something was updated
*/
-KOPETE_EXPORT bool uptateTLVs( SSI& item, const QValueList<TLV>& list );
+KOPETE_EXPORT bool uptateTLVs( SSI& item, const TQValueList<TLV>& list );
/**
* Get the value of the capability that corresponds to the value
@@ -57,34 +57,34 @@ int parseCap( char* cap );
/**
* Convert the capability to a string we can print
*/
-const QString capToString(char *cap);
+const TQString capToString(char *cap);
/**
* Parse the character array for validness and a version string
* \param buffer the buffer we'll be parsing for capabilities
* \param versionString a QString reference that will contain the
* version string of the detected client. Will be QString::null if
* no client is found
* \return a DWORD containg a bit array of the capabilities we found
*/
-DWORD parseCapabilities(Buffer &inbuf, QString &versionString);
+DWORD parseCapabilities(Buffer &inbuf, TQString &versionString);
/**
* Get the name of the capability from its number
*/
-const QString capName( int capNumber );
+const TQString capName( int capNumber );
/**
* Convert an IP address in dotted decimal notation to a
* numerical constant
*/
-DWORD getNumericalIP( const QString& address );
+DWORD getNumericalIP( const TQString& address );
/**
* Convert a numerical constant that is an IP address to
* dotted decimal format
*/
-QString getDottedDecimal( DWORD address );
+TQString getDottedDecimal( DWORD address );
}
@@ -57,34 +57,34 @@ int parseCap( char* cap );
* Parse the character array for validness and a version string
* \param buffer the buffer we'll be parsing for capabilities
- * \param versionString a QString reference that will contain the
- * version string of the detected client. Will be QString::null if
+ * \param versionString a TQString reference that will contain the
+ * version string of the detected client. Will be TQString::null if
* no client is found
* \return a DWORD containg a bit array of the capabilities we found